=======================
 Horizon Release Notes
=======================

.. toctree::
   :maxdepth: 1

   unreleased
   2025.2
   2025.1
   2024.2
   2024.1
   2023.2
   2023.1
   zed
   yoga
   xena
   wallaby
   victoria
   ussuri
   train
   stein
   rocky
   queens
   pike
   ocata
   newton
   mitaka
   liberty
   kilo
   juno
   icehouse
   havana
   grizzly
   folsom
   essex

.. toctree::
   :maxdepth: 1

   Release Notes Howto <https://docs.openstack.org/horizon/latest/contributor/contributing.html#release-notes>
